const kiwiz = {
    addInfosToDocuments: function () {
        // Edit documents table
        let documentsTable = document.querySelector('#documents_table, #orderDocumentsTabContent table.table');
        if (documentsTable == null) {
            return;
        }
        // Do not proceed if kiwizDocuments is not declared
        if (typeof (kiwizDocuments) == 'undefined') {
            return;
        }

        // Add new column: "Kiwiz"
        documentsTable.querySelector('thead > tr > th:last-child').insertAdjacentHTML('beforebegin', '<th><span class="title_box">Kiwiz</span></th>');
        // Add information to each document
        documentsTable.querySelectorAll('tbody > tr').forEach(function (tr) {
            // Retrieve type of document
            let docId = tr.getAttribute('id');
            if (docId == null) {
                // Retrieve document id using available links
                let documentLink = tr.querySelector('td > a');
                if (documentLink == null) {
                    return;
                }
                let documentURL = new URL(documentLink.getAttribute('href'));
                if (documentURL.searchParams.get('id_order_invoice') != null) {
                    docId = 'invoice_' + documentURL.searchParams.get('id_order_invoice');
                } else if (documentURL.searchParams.get('id_order_slip') != null) {
                    docId = 'orderslip_' + documentURL.searchParams.get('id_order_slip');
                } else {
                    return;
                }
                // Set a specific id to the <tr> so we can proceed
                tr.setAttribute('id', docId);
            }
            if (typeof (kiwizDocuments[docId]) != 'undefined') {
                tr.querySelector('td:last-child').insertAdjacentHTML('beforebegin', kiwizDocuments[docId]['state']);
            }
        });

        // Insert Kiwiz doc info after each document
        for (docId in kiwizDocuments) {
            documentsTable.querySelector('tbody tr#' + docId).insertAdjacentHTML('afterend', kiwizDocuments[docId]['infos']);
        }
        // Toggle display of Kiwiz doc info on click
        document.querySelectorAll('.kiwiz-see-infos').forEach(function (link) {
            link.addEventListener('click', function (event) {
                event.preventDefault();
                documentsTable.querySelector(link.getAttribute('href')).classList.toggle('hide');
                documentsTable.querySelector(link.getAttribute('href')).classList.toggle('d-none');
            });
        });
    },

    addBulkActions: function () {
        let bulkActionDropDown = document.querySelector('.bulk-actions ul li:last-child');
        if (bulkActionDropDown == null || typeof (kiwizActions) == 'undefined' || typeof (kiwizActions.bulk) == 'undefined') {
            return;
        }
        bulkActionDropDown.insertAdjacentHTML('afterend', kiwizActions.bulk);
    },

    moveStateBlock: function() {
        let kiwizStateBlock = document.querySelector('#kiwiz-sync-state');
        if (kiwizStateBlock == null || kiwizStateBlock.getAttribute('move-to') == null) {
            return;
        }

        let moveTo = document.querySelector(kiwizStateBlock.getAttribute('move-to'));
        if (moveTo == null) {
            return;
        }
        moveTo.append(kiwizStateBlock);
    }
};

document.addEventListener("DOMContentLoaded", function () {
    kiwiz.moveStateBlock();
    kiwiz.addInfosToDocuments();
    kiwiz.addBulkActions();
});
